from draughts.core.game import Game
from draughts.core.move import StandardMove
from draughts.core.variant import Board, Move, WHITE, BLACK

__author__ = "Ioannis Pantidis"
__copyright__ = "2021-2022, " + __author__
__version__ = "0.6.2"
